====================================
select_fields_table_model
====================================

.. FIXME: problems with this module
    ... automodule:: mdaviz.select_fields_table_model
        :members:
        :private-members:
